Page 25 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 25

Home

    and Persia. On the one hand Eastern mysticism, on the
    other Oriental love of intrigue, framed the systems later
    to be transported to the West with results so tremendous
    and far-reaching. !

    Much of the suffering of the human race has come
    about as a result of those secret societies and their

    successors. The "results so tremendous and far reaching"
    referred to by Webster have been a disaster for the well-
    being of the inhabitants of planet earth, and have
    repeatedly blocked spiritual and material progress.

    The British historian, John Robison, (1798) had this

    But not only are secret societies dangerous, but all
    societies whose object is mysterious. The whole history
    of man is a proof of this position. In no age or country
    has there ever appeared a mysterious association which
    did not in time become a public nuisance”

    existing during the middle ages gives an insight into the
    general duplicity and propensity for evil common to
    secret societies.

    One of the prominent secret societies of this period
    was an order know as The Assassins. In this order drugs
    were used to recruit young men to become professional
    assassins in order to forward the designs of their masters.

    The young man whom the Assassins desired to recruit
    was introduced to the Grand Master of the Order and

    20

    The Secret Side of History

    to say about secret societies:

    An examination of a few of the secret societies

    drugged. While unconscious, he was carried into a